summaryrefslogtreecommitdiffstats
path: root/src/lib/dhcpsrv/iterative_allocation_state.h
diff options
context:
space:
mode:
authorMarcin Siodelski <marcin@isc.org>2022-11-16 11:18:49 +0100
committerMarcin Siodelski <marcin@isc.org>2022-11-21 08:52:03 +0100
commit3bfcf6b85a5f9f5a376162f324fdac1910bc4782 (patch)
treef2935acf61c6b50aa6c0c901ae968ebc716d1fb6 /src/lib/dhcpsrv/iterative_allocation_state.h
parent[#2348] Code alignment fix (diff)
downloadkea-3bfcf6b85a5f9f5a376162f324fdac1910bc4782.tar.xz
kea-3bfcf6b85a5f9f5a376162f324fdac1910bc4782.zip
[#2348] Addressed review comments
- Remove unused AllocEngine ctor parameter - Simplify locks - Use default keyword instead of an empty implementation in dtors - Fix typos
Diffstat (limited to 'src/lib/dhcpsrv/iterative_allocation_state.h')
-rw-r--r--src/lib/dhcpsrv/iterative_allocation_state.h24
1 files changed, 4 insertions, 20 deletions
diff --git a/src/lib/dhcpsrv/iterative_allocation_state.h b/src/lib/dhcpsrv/iterative_allocation_state.h
index 50ca973b27..278c09fed3 100644
--- a/src/lib/dhcpsrv/iterative_allocation_state.h
+++ b/src/lib/dhcpsrv/iterative_allocation_state.h
@@ -53,7 +53,7 @@ public:
/// @return last allocated address or prefix of a given type.
asiolink::IOAddress getLastAllocated(Lease::Type type) const;
- /// @brief Sets last alocated address or prefix.
+ /// @brief Sets last allocated address or prefix.
///
/// @param type type of the last allocated lease set.
/// @param address an address or prefix last allocated.
@@ -61,22 +61,6 @@ public:
private:
- /// @brief Returns last allocated address or prefix.
- ///
- /// It must be called in the thread-safe context.
- ///
- /// @param type type of the last allocated lease to be returned.
- /// @return last allocated address or prefix of a given type.
- asiolink::IOAddress getLastAllocatedInternal(Lease::Type type) const;
-
- /// @brief Sets last alocated address or prefix.
- ///
- /// It must be called in the thread-safe context.
- ///
- /// @param type type of the last allocated lease set.
- /// @param address an address or prefix last allocated.
- void setLastAllocatedInternal(Lease::Type type, const asiolink::IOAddress& address);
-
/// @brief Last allocated address.
///
/// This is the last allocated address that was previously allocated from
@@ -85,16 +69,16 @@ private:
/// removing a pool, restarting or changing allocation algorithms. For
/// that purpose it should be only considered a help that should not be
/// fully trusted.
- asiolink::IOAddress last_allocated_ia_;
+ asiolink::IOAddress last_allocated_address_;
/// @brief Last allocated temporary address.
///
/// See @ref last_allocated_ia_ for details.
asiolink::IOAddress last_allocated_ta_;
/// @brief Last allocated IPv6 prefix.
///
/// See @ref last_allocated_ia_ for details.
asiolink::IOAddress last_allocated_pd_;
};
@@ -85,16 +69,16 @@ private:
/// @brief Last allocated temporary address.
///
- /// See @ref last_allocated_ia_ for details.
+ /// See @ref last_allocated_address_ for details.
asiolink::IOAddress last_allocated_ta_;
/// @brief Last allocated IPv6 prefix.
@@ -85,16 +69,16 @@ private:
/// @brief Last allocated IPv6 prefix.
///
- /// See @ref last_allocated_ia_ for details.
+ /// See @ref last_allocated_address_ for details.
asiolink::IOAddress last_allocated_pd_;
};